@@ -42,6 +42,8 @@ class TorchFitter:
                  verbose=0,
                  validation_scheduler=True,
                  step_scheduler=False):
+        if type(loss) == type:
+            loss = loss()
         self.loss_function = loss
 
         self.epoch = 0  # current epoch
